==> zio-aws-inspector2_2.12-5.17.214.1-sources.jar: zio/aws/inspector2/model/ResourceDetails.scala <==
package zio.aws.inspector2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ResourceDetails(
    awsEc2Instance: Optional[zio.aws.inspector2.model.AwsEc2InstanceDetails] =
      Optional.Absent,
    awsEcrContainerImage: Optional[
      zio.aws.inspector2.model.AwsEcrContainerImageDetails
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.inspector2.model.ResourceDetails = {
    import ResourceDetails.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.inspector2.model.ResourceDetails
      .builder()
      .optionallyWith(awsEc2Instance.map(value => value.buildAwsValue()))(
        _.awsEc2Instance
      )
      .optionallyWith(awsEcrContainerImage.map(value => value.buildAwsValue()))(
        _.awsEcrContainerImage
      )
      .build()
  }
  def asReadOnly: zio.aws.inspector2.model.ResourceDetails.ReadOnly =
    zio.aws.inspector2.model.ResourceDetails.wrap(buildAwsValue())
}
object ResourceDetails {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.inspector2.model.ResourceDetails
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.inspector2.model.ResourceDetails =
      zio.aws.inspector2.model.ResourceDetails(
        awsEc2Instance.map(value => value.asEditable),
        awsEcrContainerImage.map(value => value.asEditable)
      )
    def awsEc2Instance
        : Optional[zio.aws.inspector2.model.AwsEc2InstanceDetails.ReadOnly]
    def awsEcrContainerImage: Optional[
      zio.aws.inspector2.model.AwsEcrContainerImageDetails.ReadOnly
    ]
    def getAwsEc2Instance: ZIO[
      Any,
      AwsError,
      zio.aws.inspector2.model.AwsEc2InstanceDetails.ReadOnly
    ] = AwsError.unwrapOptionField("awsEc2Instance", awsEc2Instance)
    def getAwsEcrContainerImage: ZIO[
      Any,
      AwsError,
      zio.aws.inspector2.model.AwsEcrContainerImageDetails.ReadOnly
    ] = AwsError.unwrapOptionField("awsEcrContainerImage", awsEcrContainerImage)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.inspector2.model.ResourceDetails
  ) extends zio.aws.inspector2.model.ResourceDetails.ReadOnly {
    override val awsEc2Instance
        : Optional[zio.aws.inspector2.model.AwsEc2InstanceDetails.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.awsEc2Instance())
        .map(value =>
          zio.aws.inspector2.model.AwsEc2InstanceDetails.wrap(value)
        )
    override val awsEcrContainerImage: Optional[
      zio.aws.inspector2.model.AwsEcrContainerImageDetails.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.awsEcrContainerImage())
      .map(value =>
        zio.aws.inspector2.model.AwsEcrContainerImageDetails.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.inspector2.model.ResourceDetails
  ): zio.aws.inspector2.model.ResourceDetails.ReadOnly = new Wrapper(impl)
}

==> zio-aws-inspector2_2.13-5.17.104.9-sources.jar: zio/aws/inspector2/model/ResourceDetails.scala <==
package zio.aws.inspector2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ResourceDetails(
    awsEc2Instance: Option[zio.aws.inspector2.model.AwsEc2InstanceDetails] =
      None,
    awsEcrContainerImage: Option[
      zio.aws.inspector2.model.AwsEcrContainerImageDetails
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.inspector2.model.ResourceDetails = {
    import ResourceDetails.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.inspector2.model.ResourceDetails
      .builder()
      .optionallyWith(awsEc2Instance.map(value => value.buildAwsValue()))(
        _.awsEc2Instance
      )
      .optionallyWith(awsEcrContainerImage.map(value => value.buildAwsValue()))(
        _.awsEcrContainerImage
      )
      .build()
  }
  def asReadOnly: zio.aws.inspector2.model.ResourceDetails.ReadOnly =
    zio.aws.inspector2.model.ResourceDetails.wrap(buildAwsValue())
}
object ResourceDetails {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.inspector2.model.ResourceDetails
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.inspector2.model.ResourceDetails =
      zio.aws.inspector2.model.ResourceDetails(
        awsEc2Instance.map(value => value.asEditable),
        awsEcrContainerImage.map(value => value.asEditable)
      )
    def awsEc2Instance
        : Option[zio.aws.inspector2.model.AwsEc2InstanceDetails.ReadOnly]
    def awsEcrContainerImage
        : Option[zio.aws.inspector2.model.AwsEcrContainerImageDetails.ReadOnly]
    def getAwsEc2Instance: ZIO[
      Any,
      AwsError,
      zio.aws.inspector2.model.AwsEc2InstanceDetails.ReadOnly
    ] = AwsError.unwrapOptionField("awsEc2Instance", awsEc2Instance)
    def getAwsEcrContainerImage: ZIO[
      Any,
      AwsError,
      zio.aws.inspector2.model.AwsEcrContainerImageDetails.ReadOnly
    ] = AwsError.unwrapOptionField("awsEcrContainerImage", awsEcrContainerImage)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.inspector2.model.ResourceDetails
  ) extends zio.aws.inspector2.model.ResourceDetails.ReadOnly {
    override val awsEc2Instance
        : Option[zio.aws.inspector2.model.AwsEc2InstanceDetails.ReadOnly] =
      scala
        .Option(impl.awsEc2Instance())
        .map(value =>
          zio.aws.inspector2.model.AwsEc2InstanceDetails.wrap(value)
        )
    override val awsEcrContainerImage: Option[
      zio.aws.inspector2.model.AwsEcrContainerImageDetails.ReadOnly
    ] = scala
      .Option(impl.awsEcrContainerImage())
      .map(value =>
        zio.aws.inspector2.model.AwsEcrContainerImageDetails.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.inspector2.model.ResourceDetails
  ): zio.aws.inspector2.model.ResourceDetails.ReadOnly = new Wrapper(impl)
}
